@@ -31,17 +31,19 @@ public class DSMCCObject extends File {
     public DSMCCObject(String path)
     {
         super(path);
+        org.videolan.Logger.unimplemented(DSMCCObject.class.getName(), "");
     }
 
     public DSMCCObject(String path, String name)
     {
         super(path, name);
-
+        org.videolan.Logger.unimplemented(DSMCCObject.class.getName(), "");
     }
 
     public DSMCCObject(DSMCCObject dir, String name)
     {
         super(dir.getPath(), name);
+        org.videolan.Logger.unimplemented(DSMCCObject.class.getName(), "");
     }
 
     public boolean isLoaded()
@@ -97,11 +99,13 @@ public class DSMCCObject extends File {
 
     public static boolean prefetch(String path, byte priority)
     {
+        org.videolan.Logger.unimplemented(DSMCCObject.class.getName(), "prefetch");
         return false;
     }
 
     public static boolean prefetch(DSMCCObject dir, String path, byte priority)
     {
+        org.videolan.Logger.unimplemented(DSMCCObject.class.getName(), "prefetch");
         return false;
     }
 
@@ -109,7 +113,7 @@ public class DSMCCObject extends File {
     {
         if (loaded)
             throw new NotLoadedException();
-        
+
         loaded = false;
     }
 
@@ -144,7 +148,7 @@ public class DSMCCObject extends File {
     {
         if (!super.exists())
             throw new InvalidPathNameException();
-        
+
         listener.receiveEvent(new SuccessEvent(this));
     }
 
